@@ -1,6 +1,7 @@
 // mouse wheel: disable mozilla's ctrl+wheel zooming, and enable our own
 // set numlines to -1 to reverse directions, see bug #306110
 pref("mousewheel.withcontrolkey.action", 0);
+// NOTE! on gecko 1.9 we must set this to 1, see https://bugzilla.mozilla.org/show_bug.cgi?id=141476
 pref("mousewheel.withcontrolkey.numlines", -1);
 pref("mousewheel.withcontrolkey.sysnumlines", false);
 
@@ -72,6 +73,11 @@ pref("network.protocol-handler.warn-external.nntp", false);
 pref("network.protocol-handler.warn-external.snews", false);
 pref("network.protocol-handler.warn-external.webcal", false);
 
+// don't warn
+pref("network.protocol-handler.warn-external.rtsp", false);
+pref("network.protocol-handler.warn-external.mms", false);
+pref("network.protocol-handler.warn-external.mmsh", false);
+
 // disable xpinstall
 pref("xpinstall.enabled", false);
 
@@ -94,6 +100,8 @@ pref("browser.enable_automatic_image_resizing", false);
 pref("signon.rememberSignons", true);
 pref("signon.expireMasterPassword", false);
 pref("signon.SignonFileName", "signons.txt");
+pref("signon.SignonFileName2", "signons2.txt");
+pref("signon.autofillForms", true);
 
 // use system colours
 pref("browser.display.use_system_colors", true);
@@ -103,6 +111,9 @@ pref("browser.xul.error_pages.enabled", true);
 
 // unset weird xulrunner default UA string
 pref("general.useragent.extra.simple", "");
+pref("general.useragent.vendor", "");
+pref("general.useragent.vendorComment", "");
+pref("general.useragent.vendorSub", "");
 
 // we don't want ping(uin)s
 pref("browser.send_pings", false);
@@ -120,7 +131,7 @@ pref("general.useragent.locale", "en");
 // spellcheck
 // pref("extensions.spellcheck.inline.max-misspellings", -1);
 // 0: disabled, 1: only textareas, 2: check textareas and single-line input fields
-pref("layout.spellcheckDefault", 1);
+pref("layout.spellcheckDefault", 0);
 pref("spellchecker.dictionary", "");
 
 // print settings
@@ -129,11 +140,34 @@ pref("print.use_global_printsettings", false);
 pref("print.save_print_settings", false);
 pref("print.show_print_progress", true);
 pref("print.printer_list", "");
-pref("postscript.enabled", true);
-pref("postscript.cups.enabled", false);
+pref("print.postscript.enabled", true);
+pref("print.postscript.cups.enabled", false);
+// deactivate PAPI too (will be added in https://bugzilla.mozilla.org/show_bug.cgi?id=317450)
+pref("print.postscript.papi.enabled", false);
+
+// print margins used for the page header and footer, measured in hundredths of an inch
+// see http://bugzilla.gnome.org/show_bug.cgi?id=346110
+pref("print.printer_PostScript/default.print_edge_bottom", 15);
+pref("print.printer_PostScript/default.print_edge_left", 15);
+pref("print.printer_PostScript/default.print_edge_right", 15);
+pref("print.printer_PostScript/default.print_edge_top", 15);
 
 // sites stealthly storing unlimited amount of data? no thanks
 pref("dom.storage.enabled", false);
 
 // warn about about:config
 pref("general.warnOnAboutConfig", true);
+
+// enable negotiate extension
+pref("network.negotiate-auth.trusted-uris", "https://");
+
+// JS annoyances
+pref("dom.disable_window_flip", true);
+
+// Whether delete and backspace should immediately delete characters not
+// visually adjacent to the caret, or adjust the visual position of the caret
+// on the first keypress and delete the character on a second keypress
+// (added in bug https://bugzilla.mozilla.org/show_bug.cgi?id=328834)
+// set to true for parity with gtk entries
+pref("bidi.edit.delete_immediately", true);
+
