@@ -14,9 +14,9 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: downloader-view.c,v 1.99 2006/09/13 11:34:12 chpe Exp $
+ *  $Id: downloader-view.c 7351 2007-09-07 23:33:54Z cosimoc $
  */
 
 #include "config.h" 
@@ -84,6 +84,7 @@ struct _DownloaderViewPrivate
 	GtkStatusIcon *status_icon;
 
 	guint idle_unref : 1;
+	guint source_id;
 };
 
 enum
@@ -173,7 +174,14 @@ downloader_view_class_init (DownloaderViewClass *klass)
 static void
 show_downloader_cb (DownloaderView *dv)
 {
-	gtk_window_present (GTK_WINDOW (dv->priv->window));
+	if (!gtk_window_has_toplevel_focus (GTK_WINDOW (dv->priv->window)))
+	{
+		gtk_window_present (GTK_WINDOW (dv->priv->window));
+	}
+	else
+	{
+		gtk_widget_hide (dv->priv->window);
+	}
 }
 
 static gboolean
@@ -205,7 +213,7 @@ show_status_icon (DownloaderView *dv)
 {
 	DownloaderViewPrivate *priv = dv->priv;
 
-	priv->status_icon = gtk_status_icon_new_from_stock (EPHY_STOCK_DOWNLOAD);
+	priv->status_icon = gtk_status_icon_new_from_stock (STOCK_DOWNLOAD);
 
 	g_signal_connect_swapped (priv->status_icon, "activate",
 				  G_CALLBACK (show_downloader_cb), dv);
@@ -282,6 +290,12 @@ downloader_view_finalize (GObject *object)
 		g_object_unref (priv->status_icon);
 		priv->status_icon = NULL;
 	}
+	
+	if (priv->source_id != 0)
+	{
+		g_source_remove (priv->source_id);
+		priv->source_id = 0;
+	}
 
 	g_hash_table_destroy (dv->priv->downloads_hash);
 
@@ -460,8 +474,6 @@ update_download_row (DownloaderView *dv, EphyDownload *download)
 	g_free (cur_progress);
 	g_free (file);
 	g_free (remaining);
-
-	update_buttons (dv);
 }
 
 static void
@@ -485,7 +497,15 @@ static void
 download_changed_cb (EphyDownload *download, DownloaderView *dv)
 {
 	update_download_row (dv, download);
-	update_status_icon (dv);
+}
+
+static gboolean
+update_buttons_timeout_cb (DownloaderView *dv)
+{
+	update_buttons (dv);
+	
+	dv->priv->source_id = 0;
+	return FALSE;
 }
 
 void
@@ -556,7 +576,8 @@ downloader_view_add_download (DownloaderView *dv,
 	{
 		g_object_unref (pixbuf);
 	}
-
+	
+	dv->priv->source_id = g_timeout_add (100, (GSourceFunc) update_buttons_timeout_cb, dv);
 }
 
 static void
@@ -705,7 +726,7 @@ downloader_view_build_ui (DownloaderView *dv)
 
 	priv->model = GTK_TREE_MODEL (liststore);
 
-	gtk_window_set_icon_name (GTK_WINDOW (priv->window), EPHY_STOCK_DOWNLOAD);
+	gtk_window_set_icon_name (GTK_WINDOW (priv->window), STOCK_DOWNLOAD);
 
 	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (priv->treeview));
 	g_signal_connect (selection, "changed", G_CALLBACK (selection_changed), dv);
