@@ -16,9 +16,9 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ContentHandler.cpp 6740 2006-12-15 14:01:58Z chpe $
+ *  $Id: ContentHandler.cpp 7426 2007-09-13 13:18:57Z chpe $
  */
 
 #include "mozilla-config.h"
@@ -93,6 +93,18 @@ GContentHandler::Show (nsIHelperAppLauncher *aLauncher,
 	/* FIXME: handle aForced / aReason argument in some way? */
 
 	mContext = aContext;
+
+	/* Check for a potential veto */
+	nsCOMPtr<nsIDOMWindow> window (do_GetInterface (aContext));
+	GtkWidget *embed = EphyUtils::FindEmbed (window);
+	if (EPHY_IS_EMBED (embed))
+	{
+		if (g_object_get_data (G_OBJECT (embed), "content-handler-deny"))
+		{
+			return NS_OK;
+		}
+	}
+
 	mLauncher = aLauncher;
 	rv = Init ();
 	NS_ENSURE_SUCCESS (rv, rv);
@@ -250,7 +262,7 @@ NS_METHOD GContentHandler::MIMEConfirmAction ()
 
 	action_label =  (mAction == CONTENT_ACTION_OPEN) ||
 			(mAction == CONTENT_ACTION_OPEN_TMP) ?
-			GTK_STOCK_OPEN : EPHY_STOCK_DOWNLOAD;
+			GTK_STOCK_OPEN : STOCK_DOWNLOAD;
 
 	mime_description = gnome_vfs_mime_get_description (mMimeType.get());
 	if (mime_description == NULL)
@@ -365,6 +377,7 @@ NS_METHOD GContentHandler::MIMEInitiateAction (void)
 	{
 		const char *id = gnome_vfs_mime_application_get_desktop_id (mHelperApp);
 
+		/* FIXME! menu editing can make this check fail!!!! */
 		if (id && strcmp (id, "epiphany.desktop") == 0)
 		{
 			mHelperApp = nsnull;
@@ -425,6 +438,8 @@ NS_METHOD GContentHandler::MIMEDoAction (void)
 		info = g_strdup_printf ("gnome-browse-to-file:%d", gtk_get_current_event_time());
 	}
 
+	/* See http://bugzilla.gnome.org/show_bug.cgi?id=456945 */
+#ifndef HAVE_GECKO_1_9
 	if (info != NULL)
 	{
 		nsString desc;
@@ -441,6 +456,7 @@ NS_METHOD GContentHandler::MIMEDoAction (void)
 	{
 		mimeInfo->SetApplicationDescription (nsString ());
 	}
+#endif /* HAVE_GECKO_1_9 */
 
 	if (mAction == CONTENT_ACTION_OPEN)
 	{
