@@ -16,9 +16,9 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: EphyAboutModule.cpp 6897 2007-02-08 22:05:51Z jframeau $
+ *  $Id: EphyAboutModule.cpp 7673 2007-11-12 00:45:53Z reinouts $
  */
 
 #include "mozilla-config.h"
@@ -419,17 +419,15 @@ EphyAboutModule::GetErrorMessage(nsIURI *aURI,
 
 		/* Translators: %s is the hostname, like "www.example.com" */
 		*aTitle = g_markup_printf_escaped
-				(_("“%s” Denied Access to Port “%d”"),
-				 host.get(), port > 0 ? port : 80);
+				(_("Access Denied to Port “%d” of “%s”"),
+				 port > 0 ? port : 80, host.get());
 		/* Translators: %s is the hostname, like "www.example.com" */
 		*aPrimary = g_markup_printf_escaped
-				(_("“%s” denied access to port “%d”."),
-				 host.get(), port > 0 ? port : 80);
-		*aSecondary = g_strdup (_("The server dropped the connection "
-					  "before any data could be read."));
-		*aTertiary = _("The server may be busy or you may have a "
-			       "network connection problem. Try again later.");
-		*aLinkIntro = _("There may be an old version of the page you wanted:");
+				(_("Access denied to port “%d” of “%s”."),
+				 port > 0 ? port : 80, host.get());
+		*aSecondary = g_strdup (_("This address uses a network port which is "
+					  "normally used for purposes other than Web browsing."));
+		*aTertiary = _("The request has been cancelled for your protection.");
 	}
 	else if (strcmp (aError, "proxyResolveFailure") == 0 ||
 		 strcmp (aError, "proxyConnectFailure") == 0)
@@ -536,9 +534,11 @@ EphyAboutModule::CreateRecoverPage(nsIURI *aRecoverURI,
 	NS_ENSURE_SUCCESS (rv, rv);
 
 	char *secondary = g_markup_printf_escaped
-		(_("The page “%s” in this tab was not fully loaded yet when "
-		   "the web browser crashed; it could have caused the crash."),
-		 url.get());
+		/* Translators: %s refers to the LSB distributor ID, for instance MandrivaLinux */
+		(_("This page was loading when the web browser closed unexpectedly. "
+		   "This might happen again if you reload the page. If it does, please report "
+		   "the problem to the %s developers."),
+		   LSB_DISTRIBUTOR);
 
 	nsCOMPtr<nsIChannel> channel;
 	rv = WritePage (aRecoverURI, uri, uri, rawurl, title.get(),
