@@ -13,9 +13,9 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: EphyBrowser.h,v 1.55 2006/10/22 17:07:56 jframeau Exp $
+ *  $Id: EphyBrowser.h 7626 2007-11-05 19:54:41Z xan $
  */
 
 #ifndef EPHY_BROWSER_H
@@ -136,7 +136,7 @@ public:
 	EphyBrowser();
 	~EphyBrowser();
 
-	nsresult Init (GtkMozEmbed *mozembed);
+	nsresult Init (EphyEmbed *embed);
 	nsresult Destroy (void);
 
 	nsresult DoCommand (const char *command);
