@@ -13,9 +13,9 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: EphyFind.cpp 6916 2007-02-23 14:21:53Z chpe $
+ *  $Id: EphyFind.cpp 7647 2007-11-07 19:39:36Z cosimoc $
  */
 
 #include "mozilla-config.h"
@@ -87,7 +87,7 @@ EphyFind::SetEmbed (EphyEmbed *aEmbed)
   mWebBrowser = nsnull;
 
   rv = NS_ERROR_FAILURE;
-  gtk_moz_embed_get_nsIWebBrowser (GTK_MOZ_EMBED (aEmbed),
+  gtk_moz_embed_get_nsIWebBrowser (GTK_MOZ_EMBED (gtk_bin_get_child (GTK_BIN (aEmbed))),
 				   getter_AddRefs (mWebBrowser));
   NS_ENSURE_TRUE (mWebBrowser, rv);
 
