@@ -36,7 +36,7 @@
  *
  * ***** END LICENSE BLOCK *****
  *
- * $Id: EphyHeaderSniffer.cpp 6589 2006-09-13 11:49:01Z chpe $
+ * $Id: EphyHeaderSniffer.cpp 7426 2007-09-13 13:18:57Z chpe $
  */
 
 #include "mozilla-config.h"
@@ -98,8 +98,9 @@ EphyHeaderSniffer::EphyHeaderSniffer (nsIWebBrowserPersist* aPersist, MozillaEmb
 	watcher->GetNewAuthPrompter (nsnull, getter_AddRefs (mAuthPrompt));
 
 	mSingle = single;
+	EphyEmbedSingle **cache_ptr = &mSingle;
 	g_object_add_weak_pointer (G_OBJECT (mSingle),
-				   (gpointer *)&mSingle);
+				   (gpointer *) cache_ptr);
 }
 
 EphyHeaderSniffer::~EphyHeaderSniffer()
@@ -108,8 +109,9 @@ EphyHeaderSniffer::~EphyHeaderSniffer()
 
 	if (mSingle)
 	{
+		EphyEmbedSingle **cache_ptr = &mSingle;
 		g_object_remove_weak_pointer (G_OBJECT (mSingle),
-					      (gpointer *)&mSingle);
+					      (gpointer *) cache_ptr);
 	}
 }
 
@@ -233,7 +235,7 @@ EphyHeaderSniffer::GetInterface(const nsIID & uuid, void * *result)
 			EphyBadCertRejector *badCertRejector = new EphyBadCertRejector ();
 			if (!badCertRejector) return NS_ERROR_OUT_OF_MEMORY;
 
-			*result = NS_STATIC_CAST(nsIBadCertListener*, badCertRejector);
+			*result = static_cast<nsIBadCertListener*>(badCertRejector);
 			NS_ADDREF (badCertRejector);
 
 			return NS_OK;
