@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: EphyUtils.cpp 6952 2007-03-11 19:42:02Z chpe $
+ *  $Id: EphyUtils.cpp 7426 2007-09-13 13:18:57Z chpe $
  */
 
 #include "mozilla-config.h"
@@ -128,7 +128,8 @@ EphyUtils::FindEmbed (nsIDOMWindow *aDOMWindow)
 
 	nsresult rv;
 	GtkWidget *mozembed;
-	rv = window->GetSiteWindow ((void **)&mozembed);
+	GtkWidget **cache_ptr = &mozembed;
+	rv = window->GetSiteWindow ((void **) cache_ptr);
 	NS_ENSURE_SUCCESS (rv, nsnull);
 
 	return mozembed;
