@@ -14,9 +14,9 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-file-chooser.c 6740 2006-12-15 14:01:58Z chpe $
+ *  $Id: ephy-file-chooser.c 7502 2007-09-28 04:59:47Z diegoe $
  */
 
 #include "config.h"
@@ -30,6 +30,7 @@
 #include "ephy-stock-icons.h"
 
 #include <gtk/gtkstock.h>
+#include <gtk/gtkimage.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
 #include <glib/gi18n.h>
 
@@ -42,6 +43,8 @@ struct _EphyFileChooserPrivate
 
 static void ephy_file_chooser_class_init	(EphyFileChooserClass *klass);
 static void ephy_file_chooser_init		(EphyFileChooser *dialog);
+static void ephy_file_chooser_image_preview	(GtkFileChooser *file_chooser, 
+				 		 gpointer user_data);
 
 enum
 {
@@ -49,6 +52,9 @@ enum
 	PROP_PERSIST_KEY
 };
 
+#define PREVIEW_WIDTH 150
+#define PREVIEW_HEIGHT 150
+
 static GObjectClass *parent_class = NULL;
 
 GType
@@ -94,6 +100,29 @@ current_folder_changed_cb (GtkFileChooser *chooser, EphyFileChooser *dialog)
 	}
 }
 
+static void
+file_chooser_response_cb (GtkWidget *widget,
+			  gint response,
+			  EphyFileChooser *dialog)
+{
+	if (response == GTK_RESPONSE_ACCEPT)
+	{
+		if (dialog->priv->persist_key != NULL)
+		{
+			char *dir, *filename;
+		    
+			filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
+
+			dir = g_path_get_dirname (filename);
+
+			eel_gconf_set_path (dialog->priv->persist_key, dir);
+
+			g_free (dir);
+			g_free (filename);
+		}
+	}
+}
+
 static void
 ephy_file_chooser_init (EphyFileChooser *dialog)
 {
@@ -165,6 +194,9 @@ ephy_file_chooser_set_persist_key (EphyFileChooser *dialog, const char *key)
 
 	g_signal_connect (dialog, "current-folder-changed",
 			  G_CALLBACK (current_folder_changed_cb), dialog);
+    
+	g_signal_connect (dialog, "response",
+			  G_CALLBACK (file_chooser_response_cb), dialog);
 }
 
 const char *
@@ -288,6 +320,34 @@ ephy_file_chooser_class_init (EphyFileChooserClass *klass)
 	g_type_class_add_private (object_class, sizeof (EphyFileChooserPrivate));
 }
 
+static void
+ephy_file_chooser_image_preview (GtkFileChooser *file_chooser, 
+				 gpointer user_data)
+{
+	char *filename;
+	GtkWidget *preview;
+	GdkPixbuf *pixbuf;
+	gboolean have_preview;
+	
+	pixbuf = NULL;
+	preview = GTK_WIDGET (user_data);
+	filename = gtk_file_chooser_get_preview_filename (file_chooser);
+	
+	if (filename)
+		pixbuf = gdk_pixbuf_new_from_file_at_size (filename, 
+					PREVIEW_WIDTH, PREVIEW_HEIGHT, NULL);
+	g_free (filename);
+	
+	have_preview = (pixbuf != NULL);
+	gtk_image_set_from_pixbuf (GTK_IMAGE (preview), pixbuf);
+	
+	if (pixbuf)
+		g_object_unref (pixbuf);
+		
+	gtk_file_chooser_set_preview_widget_active (file_chooser, have_preview);
+	
+}
+
 EphyFileChooser	*
 ephy_file_chooser_new (const char *title,
 		       GtkWidget *parent,
@@ -297,6 +357,7 @@ ephy_file_chooser_new (const char *title,
 {
 	EphyFileChooser *dialog;
 	GtkFileFilter *filter[EPHY_FILE_FILTER_LAST];
+	GtkWidget *preview;
 
 	g_return_val_if_fail (default_filter >= 0 && default_filter <= EPHY_FILE_FILTER_LAST, NULL);
 
@@ -337,6 +398,10 @@ ephy_file_chooser_new (const char *title,
 						 GTK_RESPONSE_ACCEPT);
 	}
 
+	preview = gtk_image_new ();
+	gtk_file_chooser_set_preview_widget (GTK_FILE_CHOOSER (dialog), preview);
+	g_signal_connect (dialog, "update-preview", G_CALLBACK (ephy_file_chooser_image_preview), preview);
+    
 	if (default_filter != EPHY_FILE_FILTER_NONE)
 	{
 		filter[EPHY_FILE_FILTER_ALL_SUPPORTED] =
