@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-file-helpers.c 7146 2007-07-10 22:15:04Z chpe $
+ *  $Id: ephy-file-helpers.c 7760 2007-12-07 21:46:20Z diegoe $
  */
 
 #include "config.h"
@@ -36,6 +36,7 @@
 #include <libgnomevfs/gnome-vfs-file-info.h>
 #include <libgnomevfs/gnome-vfs-ops.h>
 #include <libgnomevfs/gnome-vfs-directory.h>
+#include <libgnomevfs/gnome-vfs-xfer.h>
 #include <libxml/xmlreader.h>
 
 /* bug http://bugzilla.gnome.org/show_bug.cgi?id=156687 */
@@ -46,6 +47,7 @@
 #include <libsn/sn.h>
 #include <gdk/gdk.h>
 #include <gdk/gdkx.h>
+#include <gtk/gtkrecentmanager.h>
 
 #include <string.h>
 #include <stdlib.h>
@@ -170,7 +172,6 @@ char *
 ephy_file_desktop_dir (void)
 {
 	const char *xdg_desktop_dir;
-	char *downloads_dir;
 
 	xdg_desktop_dir = g_get_user_special_dir (G_USER_DIRECTORY_DESKTOP);
 	if (xdg_desktop_dir != NULL)
@@ -350,11 +351,8 @@ ephy_file_helpers_shutdown (void)
 	{
 		if (!keep_temp_directory)
 		{
-			/* recursively delete the contents */
+			/* recursively delete the contents and the directory */
 			ephy_file_delete_directory (tmp_dir);
-
-			/* delete the directory itself too */
-			rmdir (tmp_dir);
 		}
 
 		g_free (tmp_dir);
@@ -489,6 +487,17 @@ ephy_file_delete_on_exit (const char *path)
 	/* does nothing now */
 }
 
+void
+ephy_file_add_recent_item (const char *uri,
+			   const char *mime_type)
+{	
+	GtkRecentManager *manager = gtk_recent_manager_get_default ();
+
+	g_return_if_fail (mime_type != NULL && uri != NULL);
+
+	gtk_recent_manager_add_item (manager, uri);
+}
+
 static void
 load_mime_from_xml (void)
 {
@@ -1207,8 +1216,33 @@ ephy_file_monitor_cancel (EphyFileMonitor *monitor)
 	g_free (monitor);
 }
 
+/**
+ * ephy_file_delete_directory:
+ * @path: the path to remove
+ *
+ * Remove @path and its contents. Like calling rm -rf @path.
+ *
+ **/
 void
 ephy_file_delete_directory (const char *path)
 {
-	/* FIXME not implemented yet */
+	GList *list;
+	GnomeVFSResult ret;
+	
+	list = g_list_append (NULL, gnome_vfs_uri_new (path));
+	
+	ret = gnome_vfs_xfer_delete_list (list, GNOME_VFS_XFER_ERROR_MODE_ABORT,
+					GNOME_VFS_XFER_EMPTY_DIRECTORIES,
+					NULL, NULL);
+	
+	gnome_vfs_uri_list_free (list);
+	
+	if (ret == GNOME_VFS_OK)
+	{
+		LOG ("Deleted the profile dir '%s'", path);
+	}
+	else
+	{
+		LOG ("Couldn't delete profile dir '%s'", path);
+	}
 }
