@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-bookmark-action.c 7145 2007-07-10 18:50:48Z chpe $
+ *  $Id: ephy-bookmark-action.c 7730 2007-11-25 13:47:48Z cosimoc $
  */
 
 #include "config.h"
@@ -434,23 +434,45 @@ query_tooltip_cb (GtkWidget *proxy,
 	title = ephy_node_get_property_string (node, EPHY_NODE_BMK_PROP_TITLE);
 	location = ephy_node_get_property_string (node, EPHY_NODE_BMK_PROP_LOCATION);
 	
-	if (strstr (location, "%s") != NULL)
+	if (g_str_has_prefix (location, "javascript:"))
 	{
-		GnomeVFSURI *uri = gnome_vfs_uri_new (location);
-		if (uri != NULL)
+		text = g_strdup_printf (_("Executes the script “%s”"), title);
+	}
+	else
+	{
+		if (strstr (location, "%s") != NULL)
 		{
-			text = g_markup_printf_escaped ("%s\n%s://%s",
-							title,
-			 				gnome_vfs_uri_get_scheme (uri),
-							gnome_vfs_uri_get_host_name (uri));
-			gnome_vfs_uri_unref (uri);
+			GnomeVFSURI *uri = gnome_vfs_uri_new (location);
+			if (uri != NULL)
+			{
+				if (title[0] == '\0')
+				{
+					text = g_markup_printf_escaped ("%s://%s",
+									gnome_vfs_uri_get_scheme (uri),
+									gnome_vfs_uri_get_host_name (uri));
+				}
+				else
+				{
+					text = g_markup_printf_escaped ("%s\n%s://%s",
+									title,
+									gnome_vfs_uri_get_scheme (uri),
+									gnome_vfs_uri_get_host_name (uri));
+				}
+				gnome_vfs_uri_unref (uri);
+			}
+		}
+		if (text == NULL)
+		{
+			if (title[0] == '\0')
+			{
+				text = g_markup_printf_escaped ("%s", location);
+			}
+			else
+			{
+				text = g_markup_printf_escaped ("%s\n%s", title, location);
+			}
 		}
 	}
-	if (text == NULL)
-	{
-		text = g_markup_printf_escaped ("%s\n%s", title, location);
-	}
-
 	gtk_tooltip_set_markup (tooltip, text);
 	g_free (text);
 	
