@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-bookmarks.c 6952 2007-03-11 19:42:02Z chpe $
+ *  $Id: ephy-bookmarks.c 7687 2007-11-13 23:15:57Z xan $
  */
 
 #include "config.h"
@@ -516,6 +516,15 @@ redirect_cb (EphyHistory *history,
 	gtk_window_present (GTK_WINDOW (dialog));
 }
 
+static void
+icon_updated_cb (EphyHistory *history,
+		 const char *address,
+		 const char *icon,
+		 EphyBookmarks *eb)
+{
+	ephy_bookmarks_set_icon (eb, address, icon);
+}
+
 static void
 ephy_setup_history_notifiers (EphyBookmarks *eb)
 {
@@ -534,6 +543,8 @@ ephy_setup_history_notifiers (EphyBookmarks *eb)
 			  G_CALLBACK (history_cleared_cb), eb);
 	g_signal_connect (history, "redirect",
 			  G_CALLBACK (redirect_cb), eb);
+	g_signal_connect (history, "icon-updated",
+			  G_CALLBACK (icon_updated_cb), eb);
 }
 
 static void
@@ -1074,7 +1085,7 @@ ephy_bookmarks_init (EphyBookmarks *eb)
 	 * translated string. */
 	/* Translators: this is an automatic topic containing local
 	 * websites bookmarks autodiscovered with zeroconf. */
-	const char *bk_local_sites = Q_("bookmarks|Local Sites");
+	const char *bk_local_sites = Q_("bookmarks|Nearby Sites");
 #endif
 
 	eb->priv = EPHY_BOOKMARKS_GET_PRIVATE (eb);
@@ -1668,6 +1679,7 @@ ephy_bookmarks_get_topic_uri (EphyBookmarks *eb,
 #ifdef ENABLE_ZEROCONF
 	else if (ephy_bookmarks_get_local (eb) == node)
 	{
+		/* Note: do not change to "Nearby" because of existing custom toolbars */
 		uri = g_strdup ("topic://Special/Local");
 	}
 #endif
