@@ -13,9 +13,9 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-topic-factory-action.c 6589 2006-09-13 11:49:01Z chpe $
+ *  $Id: ephy-topic-factory-action.c 7175 2007-07-16 20:22:51Z wbolster $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -319,7 +319,7 @@ ephy_topic_factory_action_new (const char *name)
 {
 	return GTK_ACTION (g_object_new (EPHY_TYPE_TOPIC_FACTORY_ACTION,
 					 "name", name,
-					 "label", _("Quick Topic"),
+					 "label", _("Topic"),
 					 "stock-id", GTK_STOCK_ADD,
 					 NULL));
 }
