@@ -1,3 +1,4 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  *  Copyright © 2003, 2004 Marco Pesenti Gritti
  *  Copyright © 2003, 2004 Christian Persch
@@ -16,11 +17,12 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-location-action.c 7020 2007-05-01 17:13:10Z xan $
+ *  $Id: ephy-location-action.c 7695 2007-11-16 15:03:10Z xan $
  */
 
 #include "config.h"
 
+#include "ephy-embed-container.h"
 #include "ephy-location-action.h"
 #include "ephy-location-entry.h"
 #include "ephy-shell.h"
@@ -283,23 +285,24 @@ get_location_cb (EphyLocationEntry *entry,
 		EphyLocationAction *action)
 {
 	EphyLocationActionPrivate *priv = action->priv;
-	EphyTab *tab;
+	EphyEmbed *embed;
 	
-	tab = ephy_window_get_active_tab (priv->window);
-	g_return_val_if_fail (tab != NULL, NULL);
+	embed = ephy_embed_container_get_active_child 
+          (EPHY_EMBED_CONTAINER (priv->window));
 
-	return g_strdup (ephy_tab_get_address (tab));
+	return g_strdup (ephy_embed_get_address (embed));
 }
 
 static char *
 get_title_cb (EphyLocationEntry *entry,
 	      EphyLocationAction *action)
 {
-	EphyTab *tab;
+	EphyEmbed *embed;
 
-	tab = ephy_window_get_active_tab (action->priv->window);
+	embed = ephy_embed_container_get_active_child 
+          (EPHY_EMBED_CONTAINER (action->priv->window));
 
-	return g_strdup (ephy_tab_get_title (tab));
+	return g_strdup (ephy_embed_get_title (embed));
 }
 
 static void
