@@ -1,3 +1,4 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  *  Copyright © 2002 Christophe Fergeau
  *  Copyright © 2003, 2004 Marco Pesenti Gritti
@@ -17,7 +18,6 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-notebook.c 7196 2007-07-25 20:46:37Z diegoe $
  */
 
 #include "config.h"
@@ -53,9 +53,6 @@
 
 #define INSANE_NUMBER_OF_URLS 20
 
-/* Until https://bugzilla.mozilla.org/show_bug.cgi?id=296002 is fixed */
-#define KEEP_TAB_IN_SAME_TOPLEVEL
-
 #define EPHY_NOTEBOOK_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_NOTEBOOK, EphyNotebookPrivate))
 
 struct _EphyNotebookPrivate
@@ -67,9 +64,9 @@ struct _EphyNotebookPrivate
 	guint dnd_enabled : 1;
 };
 
-static void ephy_notebook_init           (EphyNotebook *notebook);
-static void ephy_notebook_class_init     (EphyNotebookClass *klass);
-static void ephy_notebook_finalize       (GObject *object);
+static void ephy_notebook_init		 (EphyNotebook *notebook);
+static void ephy_notebook_class_init	 (EphyNotebookClass *klass);
+static void ephy_notebook_finalize	 (GObject *object);
 static int  ephy_notebook_insert_page	 (GtkNotebook *notebook,
 					  GtkWidget *child,
 					  GtkWidget *tab_label,
@@ -81,7 +78,7 @@ static void ephy_notebook_remove	 (GtkContainer *container,
 static const GtkTargetEntry url_drag_types [] = 
 {
 	{ EPHY_DND_URI_LIST_TYPE,   0, 0 },
-	{ EPHY_DND_URL_TYPE,        0, 1 }
+	{ EPHY_DND_URL_TYPE,	    0, 1 }
 };
 
 enum
@@ -98,45 +95,10 @@ enum
 };
 
 static guint signals[LAST_SIGNAL];
-static GObjectClass *parent_class;
 
-GType
-ephy_notebook_get_type (void)
-{
-	static GType type = 0;
-
-	if (G_UNLIKELY (type == 0))
-	{
-		const GTypeInfo our_info =
-			{
-				sizeof (EphyNotebookClass),
-				NULL, /* base_init */
-				NULL, /* base_finalize */
-				(GClassInitFunc) ephy_notebook_class_init,
-				NULL,
-				NULL, /* class_data */
-				sizeof (EphyNotebook),
-				0, /* n_preallocs */
-				(GInstanceInitFunc) ephy_notebook_init
-			};
-
-		const GInterfaceInfo link_info =
-		{
-			NULL,
-			NULL,
-			NULL
-		};
-
-	type = g_type_register_static (GTK_TYPE_NOTEBOOK,
-				       "EphyNotebook",
-				       &our_info, 0);
-	g_type_add_interface_static (type,
-				     EPHY_TYPE_LINK,
-				     &link_info);
-	}
-
-	return type;
-}
+G_DEFINE_TYPE_WITH_CODE (EphyNotebook, ephy_notebook, GTK_TYPE_NOTEBOOK,
+			 G_IMPLEMENT_INTERFACE (EPHY_TYPE_LINK,
+						NULL))
 
 void
 ephy_notebook_set_dnd_enabled (EphyNotebook *notebook,
@@ -196,8 +158,6 @@ ephy_notebook_class_init (EphyNotebookClass *klass)
 	GtkContainerClass *container_class = GTK_CONTAINER_CLASS (klass);
 	GtkNotebookClass *notebook_class = GTK_NOTEBOOK_CLASS (klass);
 
-	parent_class = g_type_class_peek_parent (klass);
-
 	object_class->finalize = ephy_notebook_finalize;
 	object_class->get_property = ephy_notebook_get_property;
 	object_class->set_property = ephy_notebook_set_property;
@@ -215,21 +175,17 @@ ephy_notebook_class_init (EphyNotebookClass *klass)
 			      g_cclosure_marshal_VOID__OBJECT,
 			      G_TYPE_NONE,
 			      1,
-			      EPHY_TYPE_TAB);
+			      GTK_TYPE_WIDGET /* Can't use an interface type here */);
 
 	g_object_class_install_property (object_class,
 					 PROP_DND_ENABLED,
-					 g_param_spec_boolean ("dnd-enabled",
-							       "DND enabled",
-							       "Whether the notebook allows tab reordering by DND",
+					 g_param_spec_boolean ("dnd-enabled", NULL, NULL,
 							       TRUE,
 							       G_PARAM_READWRITE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
 
 	g_object_class_install_property (object_class,
 					 PROP_SHOW_TABS,
-					 g_param_spec_boolean ("show-tabs",
-							       "Show tabs",
-							       "Whether the notebook shows the tabs bar",
+					 g_param_spec_boolean ("show-tabs", NULL, NULL,
 							       TRUE,
 							       G_PARAM_READWRITE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
 
@@ -394,7 +350,7 @@ ephy_notebook_switch_page_cb (GtkNotebook *notebook,
 static void
 notebook_drag_data_received_cb (GtkWidget* widget, GdkDragContext *context,
 				gint x, gint y, GtkSelectionData *selection_data,
-				guint info, guint time, EphyTab *tab)
+				guint info, guint time, EphyEmbed *embed)
 {
 	EphyWindow *window;
 	GtkWidget *notebook;
@@ -416,8 +372,8 @@ notebook_drag_data_received_cb (GtkWidget* widget, GdkDragContext *context,
 		split = g_strsplit ((const gchar *)selection_data->data, "\n", 2);
 		if (split != NULL && split[0] != NULL && split[0][0] != '\0')
 		{
-			ephy_link_open (EPHY_LINK (notebook), split[0], tab,
-					tab ? 0 : EPHY_LINK_NEW_TAB);
+			ephy_link_open (EPHY_LINK (notebook), split[0], embed,
+					embed ? 0 : EPHY_LINK_NEW_TAB);
 		}
 		g_strfreev (split);
 	}
@@ -431,8 +387,8 @@ notebook_drag_data_received_cb (GtkWidget* widget, GdkDragContext *context,
 
 		for (i = 0; uris[i] != NULL && i < INSANE_NUMBER_OF_URLS; i++)
 		{
-			tab = ephy_link_open (EPHY_LINK (notebook), uris[i], tab, 
-					(tab && i == 0) ? 0 : EPHY_LINK_NEW_TAB);
+			embed = ephy_link_open (EPHY_LINK (notebook), uris[i], embed,
+					(embed && i == 0) ? 0 : EPHY_LINK_NEW_TAB);
 		}
 
 		g_strfreev (uris);
@@ -443,8 +399,8 @@ notebook_drag_data_received_cb (GtkWidget* widget, GdkDragContext *context,
 	       
 		text = (char *) gtk_selection_data_get_text (selection_data);
 		if (text != NULL) {
-			ephy_link_open (EPHY_LINK (notebook), text, tab,
-					tab ? 0 : EPHY_LINK_NEW_TAB);
+			ephy_link_open (EPHY_LINK (notebook), text, embed,
+					embed ? 0 : EPHY_LINK_NEW_TAB);
 			g_free (text);
 		}
 	}
@@ -527,11 +483,11 @@ ephy_notebook_finalize (GObject *object)
 
 	g_list_free (priv->focused_pages);
 
-	G_OBJECT_CLASS (parent_class)->finalize (object);
+	G_OBJECT_CLASS (ephy_notebook_parent_class)->finalize (object);
 }
 
 static void
-sync_load_status (EphyTab *tab, GParamSpec *pspec, GtkWidget *proxy)
+sync_load_status (EphyEmbed *embed, GParamSpec *pspec, GtkWidget *proxy)
 {
 	GtkWidget *spinner, *icon;
 
@@ -539,7 +495,7 @@ sync_load_status (EphyTab *tab, GParamSpec *pspec, GtkWidget *proxy)
 	icon = GTK_WIDGET (g_object_get_data (G_OBJECT (proxy), "icon"));
 	g_return_if_fail (spinner != NULL && icon != NULL);
 
-	if (ephy_tab_get_load_status (tab))
+	if (ephy_embed_get_load_status (embed))
 	{
 		gtk_widget_hide (icon);
 		gtk_widget_show (spinner);
@@ -554,19 +510,19 @@ sync_load_status (EphyTab *tab, GParamSpec *pspec, GtkWidget *proxy)
 }
 
 static void
-sync_icon (EphyTab *tab,
+sync_icon (EphyEmbed *embed,
 	   GParamSpec *pspec,
 	   GtkImage *icon)
 {
-	gtk_image_set_from_pixbuf (icon, ephy_tab_get_icon (tab));
+	gtk_image_set_from_pixbuf (icon, ephy_embed_get_icon (embed));
 }
 
 static void
-sync_label (EphyTab *tab, GParamSpec *pspec, GtkWidget *label)
+sync_label (EphyEmbed *embed, GParamSpec *pspec, GtkWidget *label)
 {
 	const char *title;
 
-	title = ephy_tab_get_title (tab);
+	title = ephy_embed_get_title (embed);
 
 	gtk_label_set_text (GTK_LABEL (label), title);
 
@@ -588,7 +544,7 @@ close_button_clicked_cb (GtkWidget *widget, GtkWidget *tab)
 static void
 tab_label_style_set_cb (GtkWidget *hbox,
 			GtkStyle *previous_style,
-		        gpointer user_data)
+			gpointer user_data)
 {
 	PangoFontMetrics *metrics;
 	PangoContext *context;
@@ -614,7 +570,7 @@ tab_label_style_set_cb (GtkWidget *hbox,
 }
 
 static GtkWidget *
-build_tab_label (EphyNotebook *nb, EphyTab *tab)
+build_tab_label (EphyNotebook *nb, EphyEmbed *embed)
 {
 	GtkWidget *hbox, *label, *close_button, *image, *spinner, *icon;
 	GtkRcStyle *rcstyle;
@@ -650,15 +606,14 @@ build_tab_label (EphyNotebook *nb, EphyTab *tab)
 	/* don't allow focus on the close button */
 	gtk_button_set_focus_on_click (GTK_BUTTON (close_button), FALSE);
 
-	rcstyle = gtk_rc_style_new ();
+	rcstyle = gtk_widget_get_modifier_style (close_button);
 	rcstyle->xthickness = rcstyle->ythickness = 0;
 	gtk_widget_modify_style (close_button, rcstyle);
-	gtk_rc_style_unref (rcstyle);
 
 	image = gtk_image_new_from_stock (GTK_STOCK_CLOSE, GTK_ICON_SIZE_MENU);
 	gtk_widget_set_tooltip_text (close_button, _("Close tab"));
 	g_signal_connect (close_button, "clicked",
-			  G_CALLBACK (close_button_clicked_cb), tab);
+			  G_CALLBACK (close_button_clicked_cb), embed);
 
 	gtk_container_add (GTK_CONTAINER (close_button), image);
 	gtk_widget_show (image);
@@ -672,7 +627,7 @@ build_tab_label (EphyNotebook *nb, EphyTab *tab)
 
 	/* Set up drag-and-drop target */
 	g_signal_connect (hbox, "drag-data-received",
-			  G_CALLBACK (notebook_drag_data_received_cb), tab);
+			  G_CALLBACK (notebook_drag_data_received_cb), embed);
 	gtk_drag_dest_set (hbox, GTK_DEST_DEFAULT_ALL,
 			   url_drag_types, G_N_ELEMENTS (url_drag_types),
 			   GDK_ACTION_MOVE | GDK_ACTION_COPY);
@@ -684,15 +639,15 @@ build_tab_label (EphyNotebook *nb, EphyTab *tab)
 	g_object_set_data (G_OBJECT (hbox), "close-button", close_button);
 
 	/* Hook the label up to the tab properties */
-	sync_icon (tab, NULL, GTK_IMAGE (icon));
-	sync_label (tab, NULL, label);
-	sync_load_status (tab, NULL, hbox);
+	sync_icon (embed, NULL, GTK_IMAGE (icon));
+	sync_label (embed, NULL, label);
+	sync_load_status (embed, NULL, hbox);
 
-	g_signal_connect_object (tab, "notify::icon",
+	g_signal_connect_object (embed, "notify::icon",
 				 G_CALLBACK (sync_icon), icon, 0);
-	g_signal_connect_object (tab, "notify::title",
+	g_signal_connect_object (embed, "notify::title",
 				 G_CALLBACK (sync_label), label, 0);
-	g_signal_connect_object (tab, "notify::load-status",
+	g_signal_connect_object (embed, "notify::load-status",
 				 G_CALLBACK (sync_load_status), hbox, 0);
 
 	return hbox;
@@ -733,17 +688,17 @@ ephy_notebook_insert_page (GtkNotebook *gnotebook,
 		g_object_unref (tab_label);
 	}
 
-	g_assert (EPHY_IS_TAB (tab_widget));
+	g_assert (EPHY_IS_EMBED (tab_widget));
 
-	tab_label = build_tab_label (notebook, EPHY_TAB (tab_widget));
+	tab_label = build_tab_label (notebook, EPHY_EMBED (tab_widget));
 
 	update_tabs_visibility (notebook, TRUE);
 
-	position = GTK_NOTEBOOK_CLASS (parent_class)->insert_page (gnotebook,
-								   tab_widget,
-								   tab_label,
-								   menu_label,
-								   position);
+	position = GTK_NOTEBOOK_CLASS (ephy_notebook_parent_class)->insert_page (gnotebook,
+										 tab_widget,
+										 tab_label,
+										 menu_label,
+										 position);
 
 	gtk_notebook_set_tab_reorderable (gnotebook, tab_widget, TRUE);
 
@@ -752,7 +707,7 @@ ephy_notebook_insert_page (GtkNotebook *gnotebook,
 
 int
 ephy_notebook_add_tab (EphyNotebook *notebook,
-		       EphyTab *tab,
+		       EphyEmbed *embed,
 		       int position,
 		       gboolean jump_to)
 {
@@ -761,18 +716,19 @@ ephy_notebook_add_tab (EphyNotebook *notebook,
 	g_return_val_if_fail (EPHY_IS_NOTEBOOK (notebook), -1);
 
 	position = gtk_notebook_insert_page (GTK_NOTEBOOK (notebook),
-					     GTK_WIDGET (tab),
+					     GTK_WIDGET (embed),
 					     NULL,
 					     position);
 
 	/* FIXME gtk bug! */
+	/* FIXME: this should be fixed in gtk 2.12; check & remove this! */
 	/* The signal handler may have reordered the tabs */
-	position = gtk_notebook_page_num (gnotebook, GTK_WIDGET (tab));
+	position = gtk_notebook_page_num (gnotebook, GTK_WIDGET (embed));
 
 	if (jump_to)
 	{
 		gtk_notebook_set_current_page (gnotebook, position);
-		g_object_set_data (G_OBJECT (tab), "jump_to",
+		g_object_set_data (G_OBJECT (embed), "jump_to",
 				   GINT_TO_POINTER (jump_to));
 
 	}
@@ -820,7 +776,7 @@ ephy_notebook_remove (GtkContainer *container,
 	GtkWidget *tab_label, *tab_label_label, *tab_label_icon;
 	int position, curr;
 
-	g_assert (EPHY_IS_TAB (tab_widget));
+	g_assert (EPHY_IS_EMBED (tab_widget));
 
 	/* Remove the page from the focused pages list */
 	priv->focused_pages =  g_list_remove (priv->focused_pages, tab_widget);
@@ -843,9 +799,9 @@ ephy_notebook_remove (GtkContainer *container,
 	g_signal_handlers_disconnect_by_func
 		(tab_widget, G_CALLBACK (sync_label), tab_label_label);
 	g_signal_handlers_disconnect_by_func
-		(tab_widget, G_CALLBACK (sync_load_status), tab_label);
+	  (tab_widget, G_CALLBACK (sync_load_status), tab_label);
 
-	GTK_CONTAINER_CLASS (parent_class)->remove (container, tab_widget);
+	GTK_CONTAINER_CLASS (ephy_notebook_parent_class)->remove (container, tab_widget);
 
 	update_tabs_visibility (notebook, FALSE);
 
