@@ -14,9 +14,9 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-shell.h,v 1.38.2.2 2006/11/05 20:15:25 jframeau Exp $
+ *  $Id: ephy-shell.h 7580 2007-10-28 13:02:28Z chpe $
  */
 
 #ifndef EPHY_SHELL_H
@@ -25,7 +25,7 @@
 #include "ephy-embed-shell.h"
 #include "ephy-bookmarks.h"
 #include "ephy-window.h"
-#include "ephy-tab.h"
+#include "ephy-embed.h"
 
 #include <glib-object.h>
 #include <glib.h>
@@ -87,15 +87,15 @@ GType		ephy_shell_get_type			(void);
 
 EphyShell      *ephy_shell_get_default			(void);
 
-EphyTab	       *ephy_shell_new_tab			(EphyShell *shell,
+EphyEmbed      *ephy_shell_new_tab			(EphyShell *shell,
 							 EphyWindow *parent_window,
-							 EphyTab *previous_tab,
+							 EphyEmbed *previous_embed,
 							 const char *url,
 							 EphyNewTabFlags flags);
 
-EphyTab	       *ephy_shell_new_tab_full			(EphyShell *shell,
+EphyEmbed      *ephy_shell_new_tab_full			(EphyShell *shell,
 							 EphyWindow *parent_window,
-							 EphyTab *previous_tab,
+							 EphyEmbed *previous_embed,
 							 const char *url,
 							 EphyNewTabFlags flags,
 							 EphyEmbedChrome chrome,
