@@ -16,13 +16,14 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: popup-commands.c 7030 2007-05-18 17:04:53Z diegoe $
+ *  $Id: popup-commands.c 7695 2007-11-16 15:03:10Z xan $
  */
 
 #include "config.h"
 
 #include "popup-commands.h"
 #include "ephy-shell.h"
+#include "ephy-embed-container.h"
 #include "ephy-embed-factory.h"
 #include "ephy-embed-persist.h"
 #include "ephy-prefs.h"
@@ -44,17 +45,18 @@ popup_cmd_link_in_new_window (GtkAction *action,
 		              EphyWindow *window)
 {
 	EphyEmbedEvent *event;
-	EphyTab *tab;
+	EphyEmbed *embed;
 	const GValue *value;
 
-	tab = ephy_window_get_active_tab (window);
+	embed = ephy_embed_container_get_active_child 
+		(EPHY_EMBED_CONTAINER (window));
 
 	event = ephy_window_get_context_event (window);
 	g_return_if_fail (event != NULL);
 
 	value = ephy_embed_event_get_property (event, "link");
 
-	ephy_shell_new_tab (ephy_shell, NULL, tab,
+	ephy_shell_new_tab (ephy_shell, NULL, embed,
 			    g_value_get_string (value),
 			    EPHY_NEW_TAB_OPEN_PAGE |
 			    EPHY_NEW_TAB_IN_NEW_WINDOW);
@@ -65,17 +67,18 @@ popup_cmd_link_in_new_tab (GtkAction *action,
 		           EphyWindow *window)
 {
 	EphyEmbedEvent *event;
-	EphyTab *tab;
+	EphyEmbed *embed;
 	const GValue *value;
 
-	tab = ephy_window_get_active_tab (window);
+	embed = ephy_embed_container_get_active_child
+		(EPHY_EMBED_CONTAINER (window));
 
 	event = ephy_window_get_context_event (window);
 	g_return_if_fail (event != NULL);
 
 	value = ephy_embed_event_get_property (event, "link");
 
-	ephy_shell_new_tab (ephy_shell, window, tab,
+	ephy_shell_new_tab (ephy_shell, window, embed,
 			    g_value_get_string (value),
 			    EPHY_NEW_TAB_OPEN_PAGE |
 			    EPHY_NEW_TAB_IN_EXISTING_WINDOW);
@@ -204,7 +207,7 @@ save_property_url (GtkAction *action,
 	event = ephy_window_get_context_event (window);
 	g_return_if_fail (event != NULL);
 
-	embed = ephy_window_get_active_embed (window);
+	embed = ephy_embed_container_get_active_child (EPHY_EMBED_CONTAINER (window));
 	g_return_if_fail (embed != NULL);
 
 	value = ephy_embed_event_get_property (event, property);
@@ -239,7 +242,8 @@ popup_cmd_open_link (GtkAction *action,
 	const GValue *value;
 	EphyEmbed *embed;
 
-	embed = ephy_window_get_active_embed (window);
+	embed = ephy_embed_container_get_active_child 
+		(EPHY_EMBED_CONTAINER (window));
 	g_return_if_fail (embed != NULL);
 
 	event = ephy_window_get_context_event (window);
@@ -272,7 +276,7 @@ popup_cmd_save_image_as (GtkAction *action,
 			   window, TRUE, "image");
 }
 
-#define GNOME_BACKGROUND_PREFERENCES "gnome-background-properties"
+#define GNOME_APPEARANCE_PROPERTIES  "gnome-appearance-properties.desktop"
 
 static void
 background_download_completed (EphyEmbedPersist *persist)
@@ -284,16 +288,20 @@ background_download_completed (EphyEmbedPersist *persist)
 
 	bg = ephy_embed_persist_get_dest (persist);
 
-	g_object_unref (persist);
-
-	/* open the "Background Properties" capplet */
-	if (!ephy_file_launch_desktop_file ("background.desktop", bg, user_time))
+	/* open the Appearance Properties capplet on the Background tab */
+	if (!ephy_file_launch_desktop_file (GNOME_APPEARANCE_PROPERTIES, bg, user_time))
 	{
-		/* If the above try didn't work, then we try the Fedora name.
-		 * This is a fix for #387206, but is actually a workaround for
-		 * bugzilla.redhat.com #201867 */
-		ephy_file_launch_desktop_file ("gnome-background.desktop", bg, user_time);
+		/* Fallback for <= 2.18 desktop: try to open the "Background Properties" capplet */
+		if (!ephy_file_launch_desktop_file ("background.desktop", bg, user_time))
+		{
+			/* If the above try didn't work, then we try the Fedora name.
+			 * This is a fix for #387206, but is actually a workaround for
+			 * bugzilla.redhat.com #201867 */
+			ephy_file_launch_desktop_file ("gnome-background.desktop", bg, user_time);
+		}
 	}
+
+	g_object_unref (persist);
 }
 
 void
@@ -310,7 +318,7 @@ popup_cmd_set_image_as_background (GtkAction *action,
 	event = ephy_window_get_context_event (window);
 	g_return_if_fail (event != NULL);
 
-	embed = ephy_window_get_active_embed (window);
+	embed = ephy_embed_container_get_active_child (EPHY_EMBED_CONTAINER (window));
 	g_return_if_fail (embed != NULL);
 
 	value = ephy_embed_event_get_property (event, "image");
@@ -360,7 +368,8 @@ popup_cmd_open_frame (GtkAction *action,
 	char *location;
 	EphyEmbed *embed;
 
-	embed = ephy_window_get_active_embed (window);
+	embed = ephy_embed_container_get_active_child 
+		(EPHY_EMBED_CONTAINER (window));
 	g_return_if_fail (embed != NULL);
 
 	location = ephy_embed_get_location (embed, FALSE);
@@ -464,7 +473,8 @@ popup_cmd_open_image (GtkAction *action,
 	event = ephy_window_get_context_event (window);
 	g_return_if_fail (event != NULL);
 
-	embed = ephy_window_get_active_embed (window);
+	embed = ephy_embed_container_get_active_child 
+		(EPHY_EMBED_CONTAINER (window));
 	g_return_if_fail (embed != NULL);
 
 	value = ephy_embed_event_get_property (event, "image");
