@@ -1,3 +1,4 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  *  Copyright © 2000-2004 Marco Pesenti Gritti
  *
@@ -13,13 +14,14 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: window-commands.c,v 1.201 2006/12/17 19:04:48 chpe Exp $
+ *  $Id: window-commands.c 7709 2007-11-16 23:32:41Z xan $
  */
 
 #include "config.h"
 
+#include "ephy-embed-container.h"
 #include "ephy-embed-shell.h"
 #include "ephy-embed-single.h"
 #include "ephy-shell.h"
@@ -94,11 +96,12 @@ window_cmd_file_print_preview (GtkAction *action,
 {
 	EphyEmbed *embed;
 
-	embed = ephy_window_get_active_embed (window);
+	embed = ephy_embed_container_get_active_child 
+          (EPHY_EMBED_CONTAINER (window));
 	g_return_if_fail (EPHY_IS_EMBED (embed));
 
 	ephy_embed_set_print_preview_mode (embed, TRUE);
-	ephy_window_set_print_preview (window, TRUE);
+	_ephy_window_set_print_preview (window, TRUE);
 }
 
 void
@@ -107,7 +110,8 @@ window_cmd_file_print (GtkAction *action,
 {
 	EphyEmbed *embed;
 
-	embed = ephy_window_get_active_embed (window);
+	embed = ephy_embed_container_get_active_child 
+          (EPHY_EMBED_CONTAINER (window));
 	g_return_if_fail (EPHY_IS_EMBED (embed));
 
 	ephy_embed_print (embed);
@@ -117,18 +121,15 @@ void
 window_cmd_file_send_to	(GtkAction *action,
 			 EphyWindow *window)
 {
-	EphyTab *tab;
 	EphyEmbed *embed;
 	char *url, *location, *title;
 
-	tab = ephy_window_get_active_tab (window);
-	g_return_if_fail (tab != NULL);
-
-	embed = ephy_window_get_active_embed (window);
+	embed = ephy_embed_container_get_active_child 
+          (EPHY_EMBED_CONTAINER (window));
 	g_return_if_fail (embed != NULL);
 
-	location = gnome_vfs_escape_string (ephy_tab_get_address (tab));
-	title = gnome_vfs_escape_string (ephy_tab_get_title (tab));
+	location = gnome_vfs_escape_string (ephy_embed_get_address (embed));
+	title = gnome_vfs_escape_string (ephy_embed_get_title (embed));
 
 	url = g_strconcat ("mailto:",
                            "?Subject=", title,
@@ -181,7 +182,8 @@ window_cmd_view_stop (GtkAction *action,
 {
 	EphyEmbed *embed;
 	
-	embed = ephy_window_get_active_embed (window);
+	embed = ephy_embed_container_get_active_child 
+          (EPHY_EMBED_CONTAINER (window));
 	g_return_if_fail (embed != NULL);
 
 	gtk_widget_grab_focus (GTK_WIDGET (embed));
@@ -195,7 +197,8 @@ window_cmd_view_reload (GtkAction *action,
 {
 	EphyEmbed *embed;
 
-	embed = ephy_window_get_active_embed (window);
+	embed = ephy_embed_container_get_active_child 
+          (EPHY_EMBED_CONTAINER (window));
 	g_return_if_fail (embed != NULL);
 
 	gtk_widget_grab_focus (GTK_WIDGET (embed));
@@ -219,18 +222,15 @@ void
 window_cmd_file_bookmark_page (GtkAction *action,
 			       EphyWindow *window)
 {
-	EphyTab *tab;
 	EphyEmbed *embed;
 
-	tab = ephy_window_get_active_tab (window);
-	g_return_if_fail (tab != NULL);
-
-	embed = ephy_window_get_active_embed (window);
+	embed = ephy_embed_container_get_active_child 
+          (EPHY_EMBED_CONTAINER (window));
 	g_return_if_fail (embed != NULL);
 
 	ephy_bookmarks_ui_add_bookmark (GTK_WINDOW (window),
-					ephy_tab_get_address (tab),
-					ephy_tab_get_title (tab));
+					ephy_embed_get_address (embed),
+					ephy_embed_get_title (embed));
 }
 
 static void
@@ -283,7 +283,7 @@ window_cmd_file_save_as (GtkAction *action,
 	EphyEmbed *embed;
 	EphyEmbedPersist *persist;
 
-	embed = ephy_window_get_active_embed (window);
+	embed = ephy_embed_container_get_active_child (EPHY_EMBED_CONTAINER (window));
 	g_return_if_fail (embed != NULL);
 
 	persist = EPHY_EMBED_PERSIST
@@ -320,7 +320,7 @@ window_cmd_file_close_window (GtkAction *action,
 		              EphyWindow *window)
 {
 	GtkWidget *notebook;
-	EphyTab *tab;
+	EphyEmbed *embed;
 
 	notebook = ephy_window_get_notebook (window);
 
@@ -330,10 +330,10 @@ window_cmd_file_close_window (GtkAction *action,
 		return;
 	}
 
-	tab = ephy_window_get_active_tab (window);
-	g_return_if_fail (tab != NULL);
+	embed = ephy_embed_container_get_active_child (EPHY_EMBED_CONTAINER (window));
+	g_return_if_fail (embed != NULL);
 
-	g_signal_emit_by_name (notebook, "tab-close-request", tab);
+	g_signal_emit_by_name (notebook, "tab-close-request", embed);
 }
 
 void
@@ -383,7 +383,7 @@ window_cmd_edit_cut (GtkAction *action,
 	else
 	{
 		EphyEmbed *embed;
-		embed = ephy_window_get_active_embed (window);
+		embed = ephy_embed_container_get_active_child (EPHY_EMBED_CONTAINER (window));
 		g_return_if_fail (embed != NULL);
 
 		ephy_command_manager_do_command (EPHY_COMMAND_MANAGER (embed),
@@ -405,7 +405,7 @@ window_cmd_edit_copy (GtkAction *action,
 	{
 		EphyEmbed *embed;
 
-		embed = ephy_window_get_active_embed (window);
+		embed = ephy_embed_container_get_active_child (EPHY_EMBED_CONTAINER (window));
 		g_return_if_fail (embed != NULL);
 
 		ephy_command_manager_do_command (EPHY_COMMAND_MANAGER (embed),
@@ -427,7 +427,7 @@ window_cmd_edit_paste (GtkAction *action,
 	{
 		EphyEmbed *embed;
 
-		embed = ephy_window_get_active_embed (window);
+		embed = ephy_embed_container_get_active_child (EPHY_EMBED_CONTAINER (window));
 		g_return_if_fail (embed != NULL);
 
 		ephy_command_manager_do_command (EPHY_COMMAND_MANAGER (embed),
@@ -449,7 +449,7 @@ window_cmd_edit_delete (GtkAction *action,
 	{
 		EphyEmbed *embed;
 
-		embed = ephy_window_get_active_embed (window);
+		embed = ephy_embed_container_get_active_child (EPHY_EMBED_CONTAINER (window));
 		g_return_if_fail (embed != NULL);
 
 		ephy_command_manager_do_command (EPHY_COMMAND_MANAGER (embed),
@@ -471,7 +471,8 @@ window_cmd_edit_select_all (GtkAction *action,
 	{
 		EphyEmbed *embed;
 
-		embed = ephy_window_get_active_embed (window);
+		embed = ephy_embed_container_get_active_child 
+                  (EPHY_EMBED_CONTAINER (window));
 		g_return_if_fail (embed != NULL);
 
 		ephy_command_manager_do_command (EPHY_COMMAND_MANAGER (embed),
@@ -606,18 +607,15 @@ void
 window_cmd_view_page_source (GtkAction *action,
 			     EphyWindow *window)
 {
-	EphyTab *tab;
 	EphyEmbed *embed;
 	const char *address;
 	guint32 user_time;
 
-	tab = ephy_window_get_active_tab (window);
-	g_return_if_fail (tab != NULL);
-
-	embed = ephy_window_get_active_embed (window);
+	embed = ephy_embed_container_get_active_child 
+          (EPHY_EMBED_CONTAINER (window));
 	g_return_if_fail (embed != NULL);
 
-	address = ephy_tab_get_address (tab);
+	address = ephy_embed_get_address (embed);
 	user_time = gtk_get_current_event_time ();
 
 	if (g_str_has_prefix (address, "file://"))
@@ -636,7 +634,8 @@ window_cmd_view_page_security_info (GtkAction *action,
 {
 	EphyEmbed *embed;
 
-	embed = ephy_window_get_active_embed (window);
+	embed = ephy_embed_container_get_active_child 
+          (EPHY_EMBED_CONTAINER (window));
 	g_return_if_fail (EPHY_IS_EMBED (embed));
 
 	ephy_embed_show_page_certificate (embed);
@@ -659,14 +658,15 @@ window_cmd_edit_personal_data (GtkAction *action,
 		               EphyWindow *window)
 {
 	PdmDialog *dialog;
-	EphyTab *tab;
+	EphyEmbed *embed;
 	GnomeVFSURI *uri;
 	const char *host;
 
-	tab = ephy_window_get_active_tab (window);
-	if (tab == NULL) return;
+	embed = ephy_embed_container_get_active_child 
+          (EPHY_EMBED_CONTAINER (window));
+	if (embed == NULL) return;
 
-	uri = gnome_vfs_uri_new (ephy_tab_get_address (tab));
+	uri = gnome_vfs_uri_new (ephy_embed_get_address (embed));
 
 	host = uri != NULL ? gnome_vfs_uri_get_host_name (uri) : NULL;
 
@@ -738,7 +738,7 @@ window_cmd_help_about (GtkAction *action,
 		   "GNU General Public License for more details."),
 		N_("You should have received a copy of the GNU General Public License "
 		   "along with the GNOME Web Browser; if not, write to the Free Software Foundation, Inc., "
-		   "59 Temple Place, Suite 330, Boston, MA  02111-1307  USA")
+		   "51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA")
 	};
 
 	EphyEmbedShell *shell;
@@ -824,8 +824,8 @@ window_cmd_help_about (GtkAction *action,
 	single = EPHY_EMBED_SINGLE (ephy_embed_shell_get_embed_single (shell));
 
 	comments = g_strdup_printf (_("Lets you view web pages and find information on the internet.\n"
-				      "Powered by Gecko %s"),
-				      ephy_embed_single_get_backend_name (single) + strlen ("gecko-"));
+				      "Powered by %s"), ephy_embed_single_get_backend_name (single) );
+
 	licence = g_strjoin ("\n\n",
 			     _(licence_part[0]),
 			     _(licence_part[1]),
@@ -836,7 +836,7 @@ window_cmd_help_about (GtkAction *action,
 			       "name", _("GNOME Web Browser"),
 			       "version", VERSION,
 			       "copyright", "Copyright © 2002-2004 Marco Pesenti Gritti\n"
-					    "Copyright © 2003-2006 The GNOME Web Browser Developers",
+					    "Copyright © 2003-2007 The GNOME Web Browser Developers",
 			       "artists", artists,
 			       "authors", authors,
 			       "comments", comments,
@@ -946,9 +946,17 @@ window_cmd_load_location (GtkAction *action,
 
 	if (location)
 	{
-		ephy_link_open (EPHY_LINK (window), location,
-			        ephy_window_get_active_tab (window),
-				ephy_link_flags_from_current_event ());
+		EphyBookmarks *bookmarks;
+		char *address;
+
+		bookmarks = ephy_shell_get_bookmarks (ephy_shell_get_default ());
+
+		address = ephy_bookmarks_resolve_address (bookmarks, location, NULL);
+		g_return_if_fail (address != NULL);
+
+		ephy_link_open (EPHY_LINK (window), address,
+			        ephy_embed_container_get_active_child (EPHY_EMBED_CONTAINER (window)),
+				ephy_link_flags_from_current_event () | EPHY_LINK_ALLOW_FIXUP);
 	}
 }
 
